// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
// Module: BadPixelCorrector
// Author: Hassan Siddiqui
//
// Description: 
//
// Point source implementation of an Encircled Energy Corrector class
//
// Modifications: See ChangeLog
// 
// $Id: BadPixelCorrector.h,v 1.4 2011/09/29 15:07:22 rsaxton Exp $

#ifndef BadPixelCorrector_H
#define BadPixelCorrector_H

/* General */

/* SAS-specific */

/* Local */
#include "BpCorrector.h"
#include "PsfModel.h"
#include "BadPixPSFCorrector.h"
#include "MissingPixCorrector.h"

class BadPixelCorrector : public BpCorrector
{
public:

  /* Constructor */
  BadPixelCorrector(const string & eventFile, unsigned eefactor, 
                           PsfModel * psf, unsigned long flags,
                           unsigned long ccdmask);

  /* Destructor */
  ~BadPixelCorrector();

  vector<double> TotalFactor(const vector<double> & energyVector) const;

  int totalPixels() const;

private:

  /* Make a temporary file for the bad columns */
  DataSet * createTempBadColFile(const string & badpixContainer, 
                                 const string & bctempfile, 
                                 unsigned long flags) const;
  
  /* Add value to vector if not already present */
  bool checkAdd(vector<int16> rawx, int16 value, bool ignoreEdgePixels) const;

  /* Member */
  vector<MissingPixCorrector *> _bpcorr;

  DataSet * _bcset;

 /* Set the temp filename for bad column data */
  string bctempfile; 

};

#endif
