// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
// Module: DetmapPsfModel
// Author: Richard Saxton
//
// Description: 
//
// A simple model for the PSF.
// Used for prototyping; will be eventually replaced by relevant CAL fn.
//
// Modifications: See ChangeLog
// 
// $Id: DetmapPsfModel.h,v 1.6 2012/03/29 13:14:00 rsaxton Exp $

#ifndef DetmapPsfModel_H
#define DetmapPsfModel_H

/* SAS-specific */
#include "CalCommon.h"
#include "CalServer.h"
#include "EncircledEnergyDataServer.h"
#include "Region.h"

/* Local */
#include "PsfModel.h"

class DetmapPsfModel: public PsfModel
{
public:

  /*** NOTE: units for both x/y directions are 0.05 arcseconds ***/

  /* Constructor */
   DetmapPsfModel( PixelIterator * imagePixItr );    

  /* Destructor */
  ~DetmapPsfModel();

  /* Return normalized PSF function at given position */
  double psf( double x, 
	      double y) const;
  
  /* Calculate integrated PSF over a square area. The position of the centre
 * of the square is defined by the parameters centx and centy.
 * The method divides the area into nbins*nbins subelements
 * for the computation.
 * The higher nbins is, the more accurate the computation will be.
 */
  double int_psf( double xboxcentre, 
		  double yboxcentre, 
		  double xboxsize,
		  double yboxsize) const;

  double enclosed_psf( PixelIterator * pxitr ) const;

  double rad_psf() const;

  void energy(double energy);

  void setRadius(vector<double> radii);

  void setNgridEls(unsigned int NGridEls);

  string mode() const;

  void setBoxShape(ShapeBasics::ShapeType shape);

  void setFastModeFactor(double factor);

  void setSRCPOS(int SRCPOS);

  void setOrientation(double /* */) {};

  double getMajorAxis(double /* */, double /* */) const {RETURN 0.0;};

private:
  
  double _norm; // Sum of iterator values
  CoordPair _imin, _imax; // Min and max detector pixels
  double _xwid, _ywid; // Width of each pixel
  int _nx, _ny; // Image dimensions
  SImage *_dIm; // An image to hold the detector map


};

#endif

