// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
// 
// Module: RegionFunctions
// Author: Richard Saxton
//
// Modifications: See ChangeLog
// 
// $Id: RegionFunctions.h,v 1.1.1.1 2004/02/09 14:54:12 eojero Exp $

#ifndef RegionFunctions_H
#define RegionFunctions_H

// General classes

/* SAS-specific */
#include "DataSubspace.h"
#include "Region.h"
#include "ASCregion.h"

/* Local classes */
#include "PositionUtils.h"
#include "CoreData.h"

/******************************************
 *
 * class RegionFunctions
 *
 * Namespace for common DSS and region manipulation functions 
 *
 ******************************************/

class RegionFunctions
{
public:

  RegionFunctions(CoreData * coredata);
  ~RegionFunctions();

  GeoRegion region(DataSubspace * dss);
  GeoRegion region(DataSubspace * dss, bool rawonly);
  void convRawToDet(DataSubspace * dss);
  void removeFilters(DataSubspace * dss, const string & axis);
  GeoRegion rawBlockToDet(GeoRegion inRegion) const;
  DataSubspace * detDSS() const;
  GeoRegion regionToPoly(GeoRegion inRegion) const;
  vector<FShape *> shapeToPoly(FShape * element) const;
  FShape * shapeToPolyConvert(FShape * element) const;

private:

  CoreData      * _coredata;
  PositionUtils * _putils;
  DataSubspace  * _dssextra;

  bool _regPosCoords;

};

#endif

